Authors
============

Developers:

* David Lucsanyi
* Matej Arko
* Constanze Nghiem
* `Thibaut Prod'homme <thibaut.prodhomme@esa.int>`_
* `Hans Smit <hans.smit@esa.int>`_
* `Frederic Lemmel <frederic.lemmel@esa.int>`_
* `Benoit Serra <benoit.serra@eso.org>`_


Contributors:

* Elizabeth George
* Bradley Kelman
* Pierre-Elie Crouzet
* Peter Verhoeve
* Brian Shortt
* `Enrico Biancalani <https://orcid.org/0000-0002-6137-0342>`_ (mainly for the implementation of MKIDs)
* Thibault Pichon
* James Gilbert
* Lawrence Jones
* Florian Moriousef
* Vincent Goiffon
* Arthur Kadela
* Joonas Viuho